==> lire_1.5.orig.tar.gz: lire-1.5/all/lib/Lire/Config/DirectorySpec.pm <==
package Lire::Config::DirectorySpec;

use strict;

=pod

=head1 Lire::Config::DirectorySpec

Type that represents a directory.

Directory values are valid only when the path they point to exists.

=cut

use base qw/Lire::Config::ScalarSpec/;
use Lire::Utils qw(tilde_expand);
use File::Spec;

sub is_valid {
    my ( $self, $val ) = @_;

    return 0 unless defined $val;
    my $dir = $self->normalize( $val );

    return -d $dir;
}

sub normalize {
    my ( $self, $val ) = @_;

    return undef unless defined $val;

    return File::Spec->canonpath( tilde_expand( $val ) );
}

1;
__END__

=pod

=head1 VERSION

$Id: DirectorySpec.pm,v 1.1 2004/03/17 17:46:54 wsourdeau Exp $

=head1 AUTHORS

Francis J. Lacoste <flacoste@logreport.org>
Wessel Dankers <wsl@logreport.org>
Wolfgang Sourdeau <wolfgang@logreport.org>

=head1 COPYRIGHT

Copyright (C) 2002-2004  Stichting LogReport Foundation LogReport@LogReport.org

This file is part of Lire.

Lire is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program (see COPYING); if not, check with
http://www.gnu.org/copyleft/gpl.html or write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.

=cut

==> lire_2.0.1.orig.tar.gz: lire-2.0.1/all/lib/Lire/Config/DirectorySpec.pm <==
package Lire::Config::DirectorySpec;

use strict;

=pod

=head1 Lire::Config::DirectorySpec

Type that represents a directory.

Directory values are valid only when the path they point to exists.

=cut

use base qw/Lire::Config::ScalarSpec/;
use Lire::Utils qw(tilde_expand);
use File::Spec;

sub is_valid {
    my ( $self, $val ) = @_;

    return !$self->required() unless defined $val;

    my $dir = $self->normalize( $val );

    return -d $dir;
}

sub normalize {
    my ( $self, $val ) = @_;

    return undef unless defined $val;

    return File::Spec->canonpath( tilde_expand( $val ) );
}

1;
__END__

=pod

=head1 VERSION

$Id: DirectorySpec.pm,v 1.2 2004/07/21 21:28:30 flacoste Exp $

=head1 AUTHORS

Francis J. Lacoste <flacoste@logreport.org>
Wessel Dankers <wsl@logreport.org>
Wolfgang Sourdeau <wolfgang@logreport.org>

=head1 COPYRIGHT

Copyright (C) 2002-2004  Stichting LogReport Foundation LogReport@LogReport.org

This file is part of Lire.

Lire is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program (see COPYING); if not, check with
http://www.gnu.org/copyleft/gpl.html or write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.

=cut
